==========
flake8-ycm
==========

.. image:: https://img.shields.io/travis/micbou/flake8-ycm.svg?label=Linux
  :target: https://travis-ci.com/micbou/flake8-ycm

.. image:: https://img.shields.io/appveyor/ci/micbou/flake8-ycm/master.svg?label=Windows
  :target: https://ci.appveyor.com/project/micbou/flake8-ycm

.. image:: https://img.shields.io/codecov/c/github/micbou/flake8-ycm/master.svg
  :target: https://codecov.io/gh/micbou/flake8-ycm

A `Flake8 <https://flake8.readthedocs.io/en/latest/>`_ plugin that enforces
`YouCompleteMe <https://github.com/Valloric/YouCompleteMe>`_ and
`ycmd <https://github.com/Valloric/ycmd>`_ coding style.

Rules
-----

====== ===========
Code   Description
====== ===========
YCM111 indentation is not a multiple of two spaces
YCM112 expected an indented block of `n` spaces
YCM114 indentation is not a multiple of two spaces (comment)
YCM115 expected an indented block of `n` spaces (comment)
YCM201 exactly one space required after a left bracket
YCM202 exactly one space required before a right bracket
YCM204 no spaces between brackets for empty content
====== ===========
